Class: SimpleCov::BlockFilter

Inherits:
Filter
  • Object
show all
Defined in:
lib/simplecov/filter.rb,
sig/simplecov.rbs

Overview

Matches when the configured block returns truthy for the source file.

Instance Attribute Summary

Attributes inherited from Filter

#filter_argument

Instance Method Summary collapse

Methods inherited from Filter

build_filter, class_for_argument, #initialize

Constructor Details

This class inherits a constructor from SimpleCov::Filter

Instance Method Details

#matches?(source_file) ⇒ Boolean

Returns true if the block given when initializing this filter with BlockFilter.new {|src_file| ... } returns true for the given source file.

Parameters:

Returns:

  • (Boolean)


130
131
132
# File 'lib/simplecov/filter.rb', line 130

def matches?(source_file)
  filter_argument.call(source_file)
end

#path_only?Boolean

Whether the verdict depends only on the path, so it can be decided before the file has any coverage.

Returns:

  • (Boolean)


1274
# File 'sig/simplecov.rbs', line 1274

def path_only?: () -> bool