Class: SimpleCov::ExitCodes::MaximumCoverageDropCheck

Inherits:
Check
  • Object
show all
Defined in:
lib/simplecov/exit_codes/maximum_coverage_drop_check.rb

Overview

Fails when any coverage criterion has dropped by more than the configured maximum since the last recorded run.

Instance Method Summary collapse

Methods inherited from Check

#failing?, #initialize, #report

Constructor Details

This class inherits a constructor from SimpleCov::ExitCodes::Check

Instance Method Details

#exit_codeObject



8
9
10
# File 'lib/simplecov/exit_codes/maximum_coverage_drop_check.rb', line 8

def exit_code
  SimpleCov::ExitCodes::MAXIMUM_COVERAGE_DROP
end