Class: SimpleCov::GlobFilter

Inherits:
Filter
  • Object
show all
Defined in:
lib/simplecov/filter.rb,
sig/simplecov.rbs

Overview

Matches when the project path matches the configured shell glob (e.g. "lib/**/*.rb").

Instance Attribute Summary

Attributes inherited from Filter

#filter_argument

Instance Method Summary collapse

Methods inherited from Filter

build_filter, class_for_argument, #initialize

Constructor Details

This class inherits a constructor from SimpleCov::Filter

Instance Method Details

#matches?(source_file) ⇒ Boolean

Parameters:

Returns:

  • (Boolean)


140
141
142
# File 'lib/simplecov/filter.rb', line 140

def matches?(source_file)
  File.fnmatch?(filter_argument, source_file.project_filename, File::FNM_PATHNAME | File::FNM_EXTGLOB)
end

#path_only?Boolean

Whether the verdict depends only on the path, so it can be decided before the file has any coverage.

Returns:

  • (Boolean)


1284
1285
1286
# File 'sig/simplecov.rbs', line 1284

def path_only?
  true
end