Class: SimpleCov::StaticCoverageExtractor::LocationConventions::PointLocation

Inherits:
Data
  • Object
show all
Defined in:
lib/simplecov/static_coverage_extractor/location_conventions.rb

Overview

A zero-width stand-in for Prism locations, for the arms Coverage anchors to a point rather than a range. Resolvers answer whichever of a node, one of its locations, or this is nearest to hand: all three answer the four position accessors the emitted tuples are built from.

Instance Attribute Summary collapse

Instance Attribute Details

#end_columnObject (readonly)

Returns the value of attribute end_column



22
23
24
# File 'lib/simplecov/static_coverage_extractor/location_conventions.rb', line 22

def end_column
  @end_column
end

#end_lineObject (readonly)

Returns the value of attribute end_line



22
23
24
# File 'lib/simplecov/static_coverage_extractor/location_conventions.rb', line 22

def end_line
  @end_line
end

#start_columnObject (readonly)

Returns the value of attribute start_column



22
23
24
# File 'lib/simplecov/static_coverage_extractor/location_conventions.rb', line 22

def start_column
  @start_column
end

#start_lineObject (readonly)

Returns the value of attribute start_line



22
23
24
# File 'lib/simplecov/static_coverage_extractor/location_conventions.rb', line 22

def start_line
  @start_line
end