Class: SimpleCov::BlockFilter
- Inherits:
-
Filter
- Object
- Filter
- SimpleCov::BlockFilter
- Defined in:
- lib/simplecov/filter.rb
Overview
Filter that matches when the configured block returns truthy for the source file.
Instance Method Summary collapse
-
#matches?(source_file) ⇒ Boolean
Returns true if the block given when initializing this filter with BlockFilter.new {|src_file| ... } returns true for the given source file.
Instance Method Details
#matches?(source_file) ⇒ Boolean
Returns true if the block given when initializing this filter with BlockFilter.new {|src_file| ... } returns true for the given source file.
105 106 107 |
# File 'lib/simplecov/filter.rb', line 105 def matches?(source_file) filter_argument.call(source_file) end |