Module: SimpleCov::Combine::ResultsCombiner
- Extended by:
- ResultsCombiner
- Included in:
- ResultsCombiner
- Defined in:
- lib/simplecov/combine/results_combiner.rb
Instance Method Summary collapse
-
#combine(*results) ⇒ Object
Callers that read their results one at a time, to keep a big CI run's resultsets out of memory at once, should drive a
CoverageAccumulatordirectly instead of collecting the results to pass here.
Instance Method Details
#combine(*results) ⇒ Object
Callers that read their results one at a time, to keep a big CI run's
resultsets out of memory at once, should drive a CoverageAccumulator
directly instead of collecting the results to pass here.
13 14 15 16 17 |
# File 'lib/simplecov/combine/results_combiner.rb', line 13 def combine(*results) accumulator = CoverageAccumulator.new results.each { |result| accumulator.absorb(result) } accumulator.result || {} end |