Module: SimpleCov::CommandGuesser
- Defined in:
- lib/simplecov/command_guesser.rb
Class Attribute Summary collapse
- .original_program_name ⇒ Object
-
.original_run_command ⇒ Object
The original command line call that invoked the test suite.
Class Method Summary collapse
Class Attribute Details
.original_program_name ⇒ Object
26 27 28 |
# File 'lib/simplecov/command_guesser.rb', line 26 def original_program_name @original_program_name || original_run_command.to_s[/\A\s*(\S+)/, 1] end |
.original_run_command ⇒ Object
The original command line call that invoked the test suite. This has to be stored as early as possible because rake and test/unit 2 have a habit of tampering with ARGV.
9 10 11 |
# File 'lib/simplecov/command_guesser.rb', line 9 def original_run_command @original_run_command end |
Class Method Details
.guess ⇒ Object
30 31 32 33 |
# File 'lib/simplecov/command_guesser.rb', line 30 def guess framework = from_executable_name || || from_defined_constants [framework, parallel_data].compact.join(" ") end |