Module: SimpleCov::ExitCodes
- Defined in:
- lib/simplecov/exit_codes.rb,
lib/simplecov/exit_codes/exit_code_handling.rb,
lib/simplecov/exit_codes/maximum_coverage_drop_check.rb,
lib/simplecov/exit_codes/maximum_overall_coverage_check.rb,
lib/simplecov/exit_codes/minimum_coverage_by_file_check.rb,
lib/simplecov/exit_codes/minimum_overall_coverage_check.rb,
lib/simplecov/exit_codes/minimum_coverage_by_group_check.rb,
sig/simplecov.rbs,
sig/simplecov.rbs
Overview
Exit codes SimpleCov uses when a coverage check fails.
Defined Under Namespace
Modules: ExitCodeHandling, _CoverageLimits Classes: MaximumCoverageDropCheck, MaximumOverallCoverageCheck, MinimumCoverageByFileCheck, MinimumCoverageByGroupCheck, MinimumOverallCoverageCheck
Constant Summary collapse
- SUCCESS =
0- EXCEPTION =
1- MINIMUM_COVERAGE =
2- MAXIMUM_COVERAGE_DROP =
3- MAXIMUM_COVERAGE =
4
Class Method Summary collapse
-
.print_error(message) ⇒ void
Threshold-violation reports and exit-status notices: enforcement output on stderr, deliberately not routed through Kernel#warn.
Class Method Details
.print_error(message) ⇒ void
This method returns an undefined value.
Threshold-violation reports and exit-status notices: enforcement output on stderr, deliberately not routed through Kernel#warn.
19 20 21 |
# File 'lib/simplecov/exit_codes.rb', line 19 def self.print_error() $stderr.puts # rubocop:disable Style/StderrPuts end |