Class: SimpleCov::ExitCodes::MaximumCoverageDropCheck
- Inherits:
-
Object
- Object
- SimpleCov::ExitCodes::MaximumCoverageDropCheck
- Defined in:
- lib/simplecov/exit_codes/maximum_coverage_drop_check.rb
Overview
Fails when any coverage criterion has dropped by more than the configured maximum since the last recorded run.
Instance Method Summary collapse
- #exit_code ⇒ Object
- #failing? ⇒ Boolean
-
#initialize(result, maximum_coverage_drop) ⇒ MaximumCoverageDropCheck
constructor
A new instance of MaximumCoverageDropCheck.
- #report ⇒ Object
Constructor Details
#initialize(result, maximum_coverage_drop) ⇒ MaximumCoverageDropCheck
Returns a new instance of MaximumCoverageDropCheck.
8 9 10 11 |
# File 'lib/simplecov/exit_codes/maximum_coverage_drop_check.rb', line 8 def initialize(result, maximum_coverage_drop) @result = result @maximum_coverage_drop = maximum_coverage_drop end |
Instance Method Details
#exit_code ⇒ Object
21 22 23 |
# File 'lib/simplecov/exit_codes/maximum_coverage_drop_check.rb', line 21 def exit_code SimpleCov::ExitCodes::MAXIMUM_COVERAGE_DROP end |
#failing? ⇒ Boolean
13 14 15 |
# File 'lib/simplecov/exit_codes/maximum_coverage_drop_check.rb', line 13 def failing? violations.any? end |