Class: SimpleCov::Filter
- Inherits:
-
Object
- Object
- SimpleCov::Filter
- Defined in:
- lib/simplecov/filter.rb
Overview
Base filter class. Inherit from this to create custom filters, and overwrite the matches?(source_file) instance method
# A sample class that rejects all source files. class StupidFilter < SimpleCov::Filter
def matches?(source_file)
false
end
end
Direct Known Subclasses
ArrayFilter, BlockFilter, GlobFilter, RegexFilter, StringFilter
Instance Attribute Summary collapse
-
#filter_argument ⇒ Object
readonly
Returns the value of attribute filter_argument.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(filter_argument) ⇒ Filter
constructor
A new instance of Filter.
- #matches?(_source_file) ⇒ Boolean
Constructor Details
#initialize(filter_argument) ⇒ Filter
Returns a new instance of Filter.
18 19 20 |
# File 'lib/simplecov/filter.rb', line 18 def initialize(filter_argument) @filter_argument = filter_argument end |
Instance Attribute Details
#filter_argument ⇒ Object (readonly)
Returns the value of attribute filter_argument.
16 17 18 |
# File 'lib/simplecov/filter.rb', line 16 def filter_argument @filter_argument end |
Class Method Details
.build_filter(filter_argument) ⇒ Object
26 27 28 29 30 |
# File 'lib/simplecov/filter.rb', line 26 def self.build_filter(filter_argument) return filter_argument if filter_argument.is_a?(SimpleCov::Filter) class_for_argument(filter_argument).new(filter_argument) end |
.class_for_argument(filter_argument) ⇒ Object
32 33 34 35 |
# File 'lib/simplecov/filter.rb', line 32 def self.class_for_argument(filter_argument) filter_classes_by_argument_type.find { |type, _| filter_argument.is_a?(type) }&.last || raise(SimpleCov::ConfigurationError, "You have provided an unrecognized filter type") end |
Instance Method Details
#matches?(_source_file) ⇒ Boolean
22 23 24 |
# File 'lib/simplecov/filter.rb', line 22 def matches?(_source_file) raise NotImplementedError, "The base filter class is not intended for direct use" end |