Class: SimpleCov::GlobFilter

Inherits:
Filter
  • Object
show all
Defined in:
lib/simplecov/filter.rb

Overview

Filter that matches when the source file’s project path matches the configured shell glob (e.g. “lib/*/.rb”). Used by ‘cover` and `skip` when callers want glob semantics instead of the substring match of `StringFilter`.

Instance Attribute Summary

Attributes inherited from Filter

#filter_argument

Instance Method Summary collapse

Methods inherited from Filter

build_filter, class_for_argument, #initialize

Constructor Details

This class inherits a constructor from SimpleCov::Filter

Instance Method Details

#matches?(source_file) ⇒ Boolean

Returns:

  • (Boolean)


115
116
117
# File 'lib/simplecov/filter.rb', line 115

def matches?(source_file)
  File.fnmatch?(filter_argument, source_file.project_filename, File::FNM_PATHNAME | File::FNM_EXTGLOB)
end