Class: SimpleCov::SourceFile::LineBuilder
- Inherits:
-
Object
- Object
- SimpleCov::SourceFile::LineBuilder
- Defined in:
- lib/simplecov/source_file/line_builder.rb
Overview
Builds the SourceFile::Line objects for a source file from the raw
line-coverage array, applying the disabled block ranges via skipped!.
Instance Method Summary collapse
- #call ⇒ Object
-
#initialize(source_file) ⇒ LineBuilder
constructor
A new instance of LineBuilder.
Constructor Details
#initialize(source_file) ⇒ LineBuilder
Returns a new instance of LineBuilder.
8 9 10 |
# File 'lib/simplecov/source_file/line_builder.rb', line 8 def initialize(source_file) @source_file = source_file end |
Instance Method Details
#call ⇒ Object
12 13 14 15 16 |
# File 'lib/simplecov/source_file/line_builder.rb', line 12 def call lines = build_lines mark_skipped(lines, @source_file.skip_chunks_for(:line)) lines end |